Crate pkgsrc

Crate pkgsrc 

pkgsrc

Rust interface to the pkg_install database and the pkgsrc mk infrastructure.

Modules

digest
Digest hashing and validation. The Digest module is mostly a thin wrapper around the digest crate and a selection of hashes provided by the RustCrypto project, with some additional features for a pkgsrc context.
distinfo
pkgsrc distinfo file parsing and processing.
pkgdb
Module supporting the package database. WIP.
plist
Packing list parsing and generation.
summary
pkg_summary(5) parsing and generation.

Structs

Depend
Parse DEPENDS and other package dependency types.
Dewey
Package pattern matching for so-called “dewey” patterns.
DeweyError
A Dewey pattern parsing error.
Metadata
Parse metadata contained in +* files in a package archive.
Pattern
Package pattern matching.
PkgName
Parse a PKGNAME into its consituent parts.
PkgPath
Handling for PKGPATH metadata and relative package directory locations.
ScanIndex
Parse the output of make pbulk-index into individual records.

Enums

DependError
A DEPENDS parsing error.
DependType
Type of dependency (full, build, bootstrap, test, etc.)
MetadataEntry
Type of Metadata entry.
PatternError
A pattern parsing error.
PkgPathError
An invalid path was specified trying to create a new PkgPath.