PkgName

Struct PkgName 

pub struct PkgName { /* private fields */ }
Parse a PKGNAME into its constituent parts.

In pkgsrc terminology a PKGNAME is made up of three parts:

  • PKGBASE contains the name of the package
  • PKGVERSION contains the full version string
  • PKGREVISION is an optional package revision denoted by nb followed by a number.

The name and version are split at the last -, and the revision, if specified, should be located at the end of the version.

This module does not enforce strict formatting. If a PKGNAME is not well formed then values may be empty or None.

Examples

use pkgsrc::PkgName;

// A well formed package name.
let pkg = PkgName::new("mktool-1.3.2nb2");
assert_eq!(pkg.pkgname(), "mktool-1.3.2nb2");
assert_eq!(pkg.pkgbase(), "mktool");
assert_eq!(pkg.pkgversion(), "1.3.2nb2");
assert_eq!(pkg.pkgrevision(), Some(2));

// An invalid PKGREVISION that can likely only be created by accident.
let pkg = PkgName::new("mktool-1.3.2nb");
assert_eq!(pkg.pkgbase(), "mktool");
assert_eq!(pkg.pkgversion(), "1.3.2nb");
assert_eq!(pkg.pkgrevision(), Some(0));

// A "-" in the version causes an incorrect split.
let pkg = PkgName::new("mktool-1.3-2");
assert_eq!(pkg.pkgbase(), "mktool-1.3");
assert_eq!(pkg.pkgversion(), "2");
assert_eq!(pkg.pkgrevision(), None);

// Not well formed, but still accepted.
let pkg = PkgName::new("mktool");
assert_eq!(pkg.pkgbase(), "mktool");
assert_eq!(pkg.pkgversion(), "");
assert_eq!(pkg.pkgrevision(), None);

// Doesn't make any sense, but whatever!
let pkg = PkgName::new("1.0nb2");
assert_eq!(pkg.pkgbase(), "1.0nb2");
assert_eq!(pkg.pkgversion(), "");
assert_eq!(pkg.pkgrevision(), None);

Implementations

Source

impl PkgName

pub fn new(pkgname: &str) -> Self

Create a new PkgName from a str reference.

pub fn pkgname(&self) -> &str

Return a str reference containing the original PKGNAME used to create this instance.

pub fn pkgbase(&self) -> &str

Return a str reference containing the PKGBASE portion of the package name, i.e. everything up to the final - and the version number.

pub fn pkgversion(&self) -> &str

Return a str reference containing the full PKGVERSION of the package name, i.e. everything after the final -. If no - was found in the str used to create this PkgName then this will be an empty string.

pub fn pkgversion_norev(&self) -> &str

Return a str reference containing the PKGVERSION_NOREV of the package name, i.e. the version with any nb<x> revision marker stripped.

pub fn pkgrevision(&self) -> Option<i64>

Return the PKGREVISION of the package name. See pkgrevision for the parsing rules.