pkgsrc
Rust interface to the pkg_install database and the pkgsrc mk infrastructure.
Modules
- digest
- Digest hashing and validation. The
Digestmodule is mostly a thin wrapper around thedigestcrate and a selection ofhashesprovided by theRustCryptoproject, with some additional features for a pkgsrc context. - distinfo
- pkgsrc
distinfofile parsing and processing. - pkgdb
- Module supporting the package database. WIP.
- plist
- Packing list parsing and generation.
- summary
pkg_summary(5)parsing and generation.
Structs
- Depend
- Parse
DEPENDSand other package dependency types. - Dewey
- Package pattern matching for so-called “dewey” patterns.
- Dewey
Error - A
Deweypattern parsing error. - Metadata
- Parse metadata contained in
+*files in a package archive. - Pattern
- Package pattern matching.
- PkgName
- Parse a
PKGNAMEinto its consituent parts. - PkgPath
- Handling for
PKGPATHmetadata and relative package directory locations. - Scan
Index - Parse the output of
make pbulk-indexinto individual records.
Enums
- Depend
Error - A
DEPENDSparsing error. - Depend
Type - Type of dependency (full, build, bootstrap, test, etc.)
- Metadata
Entry - Type of Metadata entry.
- Pattern
Error - A pattern parsing error.
- PkgPath
Error - An invalid path was specified trying to create a new
PkgPath.